Improve this doc View Source

Simple service for logging. Default implementation safely writes the message into the browser's console (if present).

The main purpose of this service is to simplify debugging and troubleshooting.

The default is to log `debug` messages. You can use ng.$logProvider#debugEnabled to change this.

## Dependencies

- `$window`

## Methods

- ###

  `log();`

  Write a log message

- ###

  `info();`

  Write an information message

- ###

  `warn();`

  Write a warning message

- ###

  `error();`

  Write an error message

- ###

  `debug();`

  Write a debug message

## Example

Edit in Plunker

    angular.module('logExample', [])
      .controller('LogController', ['$scope', '$log', function($scope, $log) {
        $scope.$log = $log;
        $scope.message = 'Hello World!';
      }]);

    <div ng-controller="LogController">
      <p>Reload this page with open console, enter text and hit the log button...</p>
      Message:
      <input type="text" ng-model="message"/>
      <button ng-click="$log.log(message)">log</button>
      <button ng-click="$log.warn(message)">warn</button>
      <button ng-click="$log.info(message)">info</button>
      <button ng-click="$log.error(message)">error</button>
    </div>